% PLOT SETTINGS

% define commonly used grids and masks for plotting maps
par.ll_lon = linspace(0,360,360);		% standard lon grid for lat x lon ensemble
par.ll_lat = linspace(-90,90,180);		% standard lat grid for lat x lon ensemble
% load land mask
landdata = load('../data/land_mask.mat');
par.land = landdata.land_mask;
par.landlat = landdata.landlat;
par.landlon = landdata.landlon;

[lon2dgrid, lat2dgrid] = meshgrid(par.ll_lon, par.ll_lat);
[~, idx35n] = min(abs(par.ll_lat - 35));
[~, idx35s] = min(abs(par.ll_lat + 35));

% set w500 threshold for plotting region of strong ascent
par.c_2d_wcrit = 35*100/3600/24; % First number is in hPa/d. This only changes the contour in the plots. The averaged values are already processed beforehand.

% define standard set of plot sizes
par.fs = 10; % standard font size
par.fs_wide = 12; % font size for wide plots
par.ppos = [0 0 10/3 7/3]; % standard plot size
par.ppos_sq = [0 0 10/3 10/3]; % square plot size
par.ppos_wide = [0 0 13/3 7/3]; % wide plot size
par.ppos_wider = [0 0 15/3 7/3];
par.ppos_verywide = [0, 0, 33/3, 5/3];

set(0, 'DefaultLineLineWidth', 1.1); % make default lines thicker
set(0, 'DefaultFigureUnits', 'inches', 'DefaultFigurePosition', par.ppos_wide); % set this as default figure size

% use latex typography by default so math notations look sensible
set(0, 'DefaultTextInterpreter', 'latex');
set(0, 'DefaultLegendInterpreter', 'latex');
set(0, 'DefaultAxesTickLabelInterpreter', 'latex');

% define standard set of colors
par.purple = [0.494, 0.184, 0.556];
par.darkbrown = 0.2*[0.635, 0.078, 0.184];
par.brown = 0.5*[0.635, 0.078, 0.184];
par.ruby = 1/255 * [120, 15, 35];
par.maroon = [0.635, 0.078, 0.184];
par.paprika = 1/255 * [192, 51, 40];
par.orange = [0.85, 0.325, 0.098];
par.tangerine = 1/255 * [230, 131, 17];
par.yellow = [0.929, 0.694, 0.125];
par.lemongrass = 1/255 * [178,177,25];
par.aquamarine = 1/255 * [0, 191, 171];
par.green = [0.466, 0.674, 0.188];
par.cyan = [0.301, 0.745, 0.933];
par.cerulean = 1/255 * [33, 152, 215];
par.blue = [0, 0.447, 0.741];
par.darkblue = 0.5*[0, 0.447, 0.741];
par.navy = 0.2*[0, 0.447, 0.741];