function pred(rootdir, bnd, perc, type, sim, amip_models, aqua_models, option, diag_alm)

clear model op

if contains(sim{1}, 'BM')

    scheme = 'bm';

elseif contains(sim{1}, {'D'})

    scheme = 'don';

else

    scheme = 'ras';

end

if strcmp(type{1}, 'am2')
	localdir = [rootdir type{1} '/' scheme '/' sim{1} '/'];
	matfile_path = ['../matfiles/' type{1} '/' scheme '/' sim{1} '/'];
else
	localdir = [rootdir type{1} '/' sim{1} '/'];
	matfile_path = ['../matfiles/' type{1} '/' sim{1} '/'];
end

%% Load data
data_path = 'mat';
if ~isempty(option)
	data_path = ['mat_' option];
end

load(sprintf([matfile_path data_path '/p_%g_%g.mat'], bnd, perc));
load(sprintf([matfile_path data_path '/c_%g_%g.mat'], bnd, perc));

% FIXME: temporary fix for loading models with kink info - rerun proc and remove
% if strcmp(type{1}, 'cmip5')
% 	if strcmp(sim{1}, 'quad')
% 		quad_warm;
% 	else
% 		quad_all_warm;	
% 	end
% end

%% Constants/parameters
load(sprintf([matfile_path data_path '/par_%g_%g.mat'], bnd, perc));
if strcmp(option, 'virtual')
	par.virtual = 1; % enable virtual effect of water vapor
else
	par.virtual = 0;
end
if strcmp(option, 'reversible')
	par.reversible = 1; % calculate reversible adiabat
else
	par.reversible = 0;
end
if contains(option, 'frz')
	par.frz = 1; % enable freezing thermodynamics
else
	par.frz = 0; % disable freezing thermodynamics
end
par.cpl = 4186; % specific heat capacity of liquid water [J/kg/K]
par.cpi = 2108; % specific heat capacity of ice [J/kg/K]
par.pe = 0.25; % precipitation efficiency
par.al = 0.9; % re-evaporation efficiency
par.p_ref = 1000 * 100; % reference pressure for potential temperature
par.pa_kink_up = 500 * 100; % upper bound for evaluating kink
par.pa_kink_lo = 900 * 100; % lower bound for evaluating kink
par.pa_kink = 750 * 100; % evaluate kink at precise level
par.pa_eps_up_list = 200 * 100;
par.pa_eps_lo_list = 850 * 100;
par.pa_op_up = 200 * 100; % upper bound for evaluating bulk overprediction
par.pa_op_lo = 200 * 100; % lower bound for evaluating bulk overprediction 
par.pa_rh_up = 200 * 100; % upper bound for evaluating bulk relative humidity
par.pa_rh_lo = 800 * 100; % lower bound for evaluating bulk relative humidity 
par.ll_lon = linspace(0,360,360);		% standard lon grid for lat x lon ensemble
par.ll_lat = linspace(-90,90,180);		% standard lat grid for lat x lon ensemble
par.lat30 = linspace(-30, 30, par.n_lat);
par.coslat30 = cosd(par.lat30');
% load land mask
landdata = load('land_mask.mat');
par.land = landdata.land_mask;
par.landlat = landdata.landlat;
par.landlon = landdata.landlon;
% special pressure grid for calculating tropopause height
par.pa_ptrop = 100 * [linspace(1000, 210, par.n_pa/5) linspace(200, 10, par.n_pa*4/5)];

c_2dti = {};
p_2dti = {};

for eps_bnds = 1:length(par.pa_eps_up_list)

	par.pa_eps_up = par.pa_eps_up_list(eps_bnds); % upper bound for evaluating bulk entrainment
	par.pa_eps_lo = par.pa_eps_lo_list(eps_bnds); % lower bound for evaluating bulk entrainment
	[~, par.eps_up] = min(abs( par.pa - par.pa_eps_up));
	[~, par.eps_lo] = min(abs( par.pa - par.pa_eps_lo));

	model = {};

	nk = 1; wk = 1; sk = 1; ak = 1; % initialize counters for kink organization

	pb_models = CmdLineProgressBar('Analyzing model ');

	amip_counter = 1;
	aqua_counter = 1;

	for k = 1:length(models)
		pb_models.print(k, length(models));

		model{k,1} = models{k}{1};
		if strcmp(type{1}, 'am2')
			model{k,1} = 'GFDL AM2.1';
		end
		
		plot_path = pred_plot_path(k, localdir, model, '', bnd, option, perc);

		if strcmp(option, 'nonsurf')
			c_ma.ts = interp1(c_plev{k}, c_3d.ta{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(c_2d.tas{k})
			c_ma.ts = interp1(c_plev{k}, c_3d.ta{k}, c_2d.ps{k}, 'linear', 'extrap');
		else
			c_ma.ts = c_2d.tas{k};
		end
		if strcmp(option, 'nonsurf')
			c_ma.hs = interp1(c_plev{k}, c_3d.hur{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(c_2d.hurs{k})
			c_ma.hs = interp1(c_plev{k}, c_3d.hur{k}, c_2d.ps{k}, 'linear', 'extrap');
		else
			c_ma.hs = c_2d.hurs{k};
		end

		c_2d.hs{k} = c_ma.hs;
		[c_ma.ta_s, c_ma.eps, c_ma.eps_z, c_ma.eps_r, c_ma.eps_r_z, c_ma.eps_rh, c_ma.eps_rh_z, c_ma.rh_r] = comp_ma(c_3d.ta{k}, c_3d.hur{k}, c_plev{k}, c_ma.ts, c_ma.hs, c_2d.ps{k}, par);

		if strcmp(type{1}, 'am2')
			c_ma.eps = comp_romps_eps(c_3d.ta{k}, c_3d.hur{k}, c_3d.z{k}, c_3d.mc{k}, c_plev{k}, par);
			c_ma.eps_so = comp_so_eps(c_3d.ta{k}, c_3d.hur{k}, c_3d.z{k}, c_plev{k}, par);
			c_ma.eps_zx = comp_zx_eps(c_3d.ta{k}, c_3d.hur{k}, c_3d.z{k}, c_plev{k}, c_ma.ts, c_ma.hs, c_2d.ps{k},  par);
		end

		if strcmp(option, 'nonsurf')
			p_ma.ts = interp1(p_plev{k}, p_3d.ta{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(p_2d.tas{k})
			p_ma.ts = interp1(p_plev{k}, p_3d.ta{k}, p_2d.ps{k}, 'linear', 'extrap');
		else
			p_ma.ts = p_2d.tas{k};
		end
		if strcmp(option, 'nonsurf')
			p_ma.hs = interp1(p_plev{k}, p_3d.hur{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(p_2d.hurs{k})
			p_ma.hs = interp1(p_plev{k}, p_3d.hur{k}, p_2d.ps{k}, 'linear', 'extrap');
		else
			p_ma.hs = p_2d.hurs{k};
		end

		p_2d.hs{k} = p_ma.hs;
		[p_ma.ta_s, p_ma.eps, p_ma.eps_z, p_ma.eps_r, p_ma.eps_r_z, p_ma.eps_rh, p_ma.eps_rh_z, p_ma.rh_r] = comp_ma(p_3d.ta{k}, p_3d.hur{k}, p_plev{k}, p_ma.ts, p_ma.hs, p_2d.ps{k}, par);
		if strcmp(type{1}, 'am2')
			p_ma.eps = comp_romps_eps(p_3d.ta{k}, p_3d.hur{k}, p_3d.z{k}, p_3d.mc{k}, p_plev{k}, par);
			p_ma.eps_so = comp_so_eps(p_3d.ta{k}, p_3d.hur{k}, p_3d.z{k}, p_plev{k}, par);
			p_ma.eps_zx = comp_zx_eps(p_3d.ta{k}, p_3d.hur{k}, p_3d.z{k}, p_plev{k}, p_ma.ts, p_ma.hs, p_2d.ps{k},  par);
		end

		if strcmp(option, 'nonsurf')
			c_ma.idx_ts = interp1(c_plev{k}, c_3d.idx_ta{k}, par.ma_init, 'linear', 'extrap');
			c_ma.sub_ts = interp1(c_plev{k}, c_3d.sub_ta{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(c_2d.idx_tas{k})
			c_ma.idx_ts = interp1(c_plev{k}, c_3d.idx_ta{k}, c_2d.idx_ps{k}, 'linear', 'extrap');
			c_ma.sub_ts = interp1(c_plev{k}, c_3d.idx_ta{k}, c_2d.idx_ps{k}, 'linear', 'extrap');
		else
			c_ma.idx_ts = c_2d.idx_tas{k};
			c_ma.sub_ts = c_2d.sub_tas{k};
		end
		if strcmp(option, 'nonsurf')
			c_ma.idx_hs = interp1(c_plev{k}, c_3d.idx_hur{k}, par.ma_init, 'linear', 'extrap');
			c_ma.sub_hs = interp1(c_plev{k}, c_3d.sub_hur{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(c_2d.idx_hurs{k})
			c_ma.idx_hs = interp1(c_plev{k}, c_3d.idx_hur{k}, c_2d.idx_ps{k}, 'linear', 'extrap');
			c_ma.sub_hs = interp1(c_plev{k}, c_3d.sub_hur{k}, c_2d.sub_ps{k}, 'linear', 'extrap');
		else
			c_ma.idx_hs = c_2d.idx_hurs{k};
			c_ma.sub_hs = c_2d.sub_hurs{k};
		end

		c_2d.idx_hs{k} = c_ma.idx_hs;
		[c_ma.idx_ta_s, c_ma.idx_eps, c_ma.idx_eps_z, c_ma.idx_eps_r, c_ma.idx_eps_r_z, c_ma.idx_eps_rh, c_ma.idx_eps_rh_z, c_ma.idx_rh_r] = comp_ma(c_3d.idx_ta{k}, c_3d.idx_hur{k}, c_plev{k}, c_ma.idx_ts, c_ma.idx_hs, c_2d.idx_ps{k}, par);
		c_2d.sub_hs{k} = c_ma.sub_hs;
		[c_ma.sub_ta_s, c_ma.sub_eps, c_ma.sub_eps_z, c_ma.sub_eps_r, c_ma.sub_eps_r_z, c_ma.sub_eps_rh, c_ma.sub_eps_rh_z, c_ma.sub_rh_r] = comp_ma(c_3d.sub_ta{k}, c_3d.sub_hur{k}, c_plev{k}, c_ma.sub_ts, c_ma.sub_hs, c_2d.sub_ps{k}, par);
		
		if strcmp(option, 'nonsurf')
			p_ma.idx_ts = interp1(p_plev{k}, p_3d.idx_ta{k}, par.ma_init, 'linear', 'extrap');
			p_ma.sub_ts = interp1(p_plev{k}, p_3d.sub_ta{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(p_2d.idx_tas{k})
			p_ma.idx_ts = interp1(p_plev{k}, p_3d.idx_ta{k}, p_2d.idx_ps{k}, 'linear', 'extrap');
			p_ma.sub_ts = interp1(p_plev{k}, p_3d.sub_ta{k}, p_2d.sub_ps{k}, 'linear', 'extrap');
		else
			p_ma.idx_ts = p_2d.idx_tas{k};
			p_ma.sub_ts = p_2d.sub_tas{k};
		end
		if strcmp(option, 'nonsurf')
			p_ma.idx_hs = interp1(p_plev{k}, p_3d.idx_hur{k}, par.ma_init, 'linear', 'extrap');
			p_ma.sub_hs = interp1(p_plev{k}, p_3d.sub_hur{k}, par.ma_init, 'linear', 'extrap');
		elseif isempty(p_2d.idx_hurs{k})
			p_ma.idx_hs = interp1(p_plev{k}, p_3d.idx_hur{k}, p_2d.idx_ps{k}, 'linear', 'extrap');
			p_ma.sub_hs = interp1(p_plev{k}, p_3d.sub_hur{k}, p_2d.sub_ps{k}, 'linear', 'extrap');
		else
			p_ma.idx_hs = p_2d.idx_hurs{k};
			p_ma.sub_hs = p_2d.sub_hurs{k};
		end

		p_2d.idx_hs{k} = p_ma.idx_hs;
		[p_ma.idx_ta_s, p_ma.idx_eps, p_ma.idx_eps_z, p_ma.idx_eps_r, p_ma.idx_eps_r_z, p_ma.idx_eps_rh, p_ma.idx_eps_rh_z, p_ma.idx_rh_r] = comp_ma(p_3d.idx_ta{k}, p_3d.idx_hur{k}, p_plev{k}, p_ma.idx_ts, p_ma.idx_hs, p_2d.idx_ps{k}, par);
		p_2d.sub_hs{k} = p_ma.sub_hs;
		[p_ma.sub_ta_s, p_ma.sub_eps, p_ma.sub_eps_z, p_ma.sub_eps_r, p_ma.sub_eps_r_z, p_ma.sub_eps_rh, p_ma.sub_eps_rh_z, p_ma.sub_rh_r] = comp_ma(p_3d.sub_ta{k}, p_3d.sub_hur{k}, p_plev{k}, p_ma.sub_ts, p_ma.sub_hs, p_2d.sub_ps{k}, par);

		for fn = fieldnames(c_ma)'
			if ~strcmp(fn{1}, {'ts', 'hs', 'ta', 'idx_ts', 'idx_hs', 'idx_ta', 'sub_ts', 'sub_hs', 'sub_ta'})
				c_mai.(fn{1}) = interp1(c_plev{k}, c_ma.(fn{1}), par.pa);
				p_mai.(fn{1}) = interp1(c_plev{k}, p_ma.(fn{1}), par.pa);
			end
		end


		[amp_m_2d, amp_g_2d] = deal({});
		[amp_m_2d, amp_g_2d] = pred_figs(k, c_lon, c_lat, c_2d, p_2d, c_2dt, p_2dt, c_3d, p_3d, c_3di, p_3di, c_ma, p_ma, c_mai, p_mai, c_plev, p_plev, '', plot_path, bnd, model, type, sim, diag_alm, par, option, perc, amp_m_2d, amp_g_2d);

		c_ma_ens(k, :) = c_mai.ta_s;
		p_ma_ens(k, :) = p_mai.ta_s;
		pc_ma_ens(k, :) = p_mai.ta_s - c_mai.ta_s;
		c_ma_idx_ens(k, :) = c_mai.idx_ta_s;
		p_ma_idx_ens(k, :) = p_mai.idx_ta_s;
		pc_ma_idx_ens(k, :) = p_mai.idx_ta_s - c_mai.idx_ta_s;
		c_ma_sub_ens(k, :) = c_mai.sub_ta_s;
		p_ma_sub_ens(k, :) = p_mai.sub_ta_s;
		pc_ma_sub_ens(k, :) = p_mai.sub_ta_s - c_mai.sub_ta_s;

		clear p_ode c_ode

		[c_op(k), p_op(k), op(k), op_bulk(k)] = pred_op(k, c_ma, p_ma, c_3di, p_3di, '', par);
		[amp(k), amp_m(k), amp_g(k)] = pred_amp(k, c_ma, p_ma, c_3di, p_3di, c_2d, p_2d, '', par);

		c_ma.ta = c_3d.ta{k};
		p_ma.ta = p_3d.ta{k};
		c_mai.ta = c_3di.ta{k};
		p_mai.ta = p_3di.ta{k};
		[c_op_ma(k), p_op_ma(k), op_ma(k)] = pred_op_ma(c_plev{k}, c_mai, p_mai, '', par);
		[c_op_k(k), p_op_k(k), op_k(k)] = pred_op_k(c_plev{k},  c_ma, p_ma, '', par);

		p_net_eps_l_bulk(k) = bulk_avg(p_3di.net_eps_l{k}, par.pa, par);
		p_eps_bulk(k) = bulk_avg(p_3di.eps{k}, par.pa, par);
		p_eps_z_bulk(k) = bulk_avg(p_3di.eps_z{k}, par.pa, par);
		p_eps_r_z_bulk(k) = bulk_avg(p_3di.eps_r_z{k}, par.pa, par);
		p_eps_so_z_bulk(k) = bulk_avg(p_3di.eps_so_z{k}, par.pa, par);
		c_net_eps_l_bulk(k) = bulk_avg(c_3di.net_eps_l{k}, par.pa, par);
		c_eps_bulk(k) = bulk_avg(c_3di.eps{k}, par.pa, par);
		c_eps_z_bulk(k) = bulk_avg(c_3di.eps_z{k}, par.pa, par);
		c_eps_r_z_bulk(k) = bulk_avg(c_3di.eps_r_z{k}, par.pa, par);
		c_eps_so_z_bulk(k) = bulk_avg(c_3di.eps_so_z{k}, par.pa, par);

		p_hur_bulk(k) = bulk_avg_rh(p_3di.hur{k}, par.pa, par);
		c_hur_bulk(k) = bulk_avg_rh(c_3di.hur{k}, par.pa, par);

		kink_ta(k) = pred_kink(k, c_3d, p_3d, c_plev, p_plev, '', par);

		% calculate ensemble lat x lon data
		c_2dti = pred_ll_ens(k, c_2dti, c_2dt, c_lat{k}, c_lon{k}, par);
		p_2dti = pred_ll_ens(k, p_2dti, p_2dt, p_lat{k}, p_lon{k}, par);
		op_2d{k} = 100 * (p_2dti.ts300{k}-c_2dti.ts300{k} - (p_2dti.t300{k} - c_2dti.t300{k}) )./(p_2dti.t300{k} - c_2dti.t300{k});
		amp_2d{k} = 100 * (p_2dti.ts300{k}-c_2dti.ts300{k} - (p_2dti.t300{k} - c_2dti.t300{k}) )./(p_2dti.tas{k} - c_2dti.tas{k});

		if strcmp(sim{1}, 'quad_all')
			if any(contains(model{k}, amip_models))
				c_ma_ens_amip(amip_counter, :) = c_ma_ens(k, :);
				p_ma_ens_amip(amip_counter, :) = p_ma_ens(k, :);
				pc_ma_ens_amip(amip_counter, :) = pc_ma_ens(k, :);
				c_ma_idx_ens_amip(amip_counter, :) = c_ma_idx_ens(k, :);
				p_ma_idx_ens_amip(amip_counter, :) = p_ma_idx_ens(k, :);
				pc_ma_idx_ens_amip(amip_counter, :) = pc_ma_idx_ens(k, :);
				c_ma_sub_ens_amip(amip_counter, :) = c_ma_sub_ens(k, :);
				p_ma_sub_ens_amip(amip_counter, :) = p_ma_sub_ens(k, :);
				pc_ma_sub_ens_amip(amip_counter, :) = pc_ma_sub_ens(k, :);
				for fn = fieldnames(p_2d)'
					c_2d_amip.(fn{1}){amip_counter} = c_2d.(fn{1}){k};
					p_2d_amip.(fn{1}){amip_counter} = p_2d.(fn{1}){k};
				end
				for fn = fieldnames(p_3di)'
					c_3di_amip.(fn{1}){amip_counter} = c_3di.(fn{1}){k};
					p_3di_amip.(fn{1}){amip_counter} = p_3di.(fn{1}){k};
				end
				for fn = fieldnames(p_2dti)'
					c_2dti_amip.(fn{1}){amip_counter} = c_2dti.(fn{1}){k};
					p_2dti_amip.(fn{1}){amip_counter} = p_2dti.(fn{1}){k};
				end
				op_2d_amip{amip_counter} = op_2d{k};
				amip_counter = amip_counter + 1;
			end
			if any(contains(model{k}, aqua_models))
				c_ma_ens_aqua(aqua_counter, :) = c_ma_ens(k, :);
				p_ma_ens_aqua(aqua_counter, :) = p_ma_ens(k, :);
				pc_ma_ens_aqua(aqua_counter, :) = pc_ma_ens(k, :);
				c_ma_idx_ens_aqua(aqua_counter, :) = c_ma_idx_ens(k, :);
				p_ma_idx_ens_aqua(aqua_counter, :) = p_ma_idx_ens(k, :);
				pc_ma_idx_ens_aqua(aqua_counter, :) = pc_ma_idx_ens(k, :);
				c_ma_sub_ens_aqua(aqua_counter, :) = c_ma_sub_ens(k, :);
				p_ma_sub_ens_aqua(aqua_counter, :) = p_ma_sub_ens(k, :);
				pc_ma_sub_ens_aqua(aqua_counter, :) = pc_ma_sub_ens(k, :);
				for fn = fieldnames(p_2d)'
					c_2d_aqua.(fn{1}){aqua_counter} = c_2d.(fn{1}){k};
					p_2d_aqua.(fn{1}){aqua_counter} = p_2d.(fn{1}){k};
				end
				for fn = fieldnames(p_3di)'
					c_3di_aqua.(fn{1}){aqua_counter} = c_3di.(fn{1}){k};
					p_3di_aqua.(fn{1}){aqua_counter} = p_3di.(fn{1}){k};
				end
				for fn = fieldnames(p_2dti)'
					c_2dti_aqua.(fn{1}){aqua_counter} = c_2dti.(fn{1}){k};
					p_2dti_aqua.(fn{1}){aqua_counter} = p_2dti.(fn{1}){k};
				end
				op_2d_aqua{aqua_counter} = op_2d{k};
				aqua_counter = aqua_counter + 1;
			end
		end

	end

	c_ma_ens = nanmean(c_ma_ens, 1);
	p_ma_ens = nanmean(p_ma_ens, 1);
	pc_ma_ens = nanmean(pc_ma_ens, 1);
	c_ma_idx_ens = nanmean(c_ma_idx_ens, 1);
	p_ma_idx_ens = nanmean(p_ma_idx_ens, 1);
	pc_ma_idx_ens = nanmean(pc_ma_idx_ens, 1);
	c_ma_sub_ens = nanmean(c_ma_sub_ens, 1);
	p_ma_sub_ens = nanmean(p_ma_sub_ens, 1);
	pc_ma_sub_ens = nanmean(pc_ma_sub_ens, 1);

	for fn = fieldnames(c_2dti)'
		c_2dt_ens.(fn{1}) = nanmean(cat(3, c_2dti.(fn{1}){:}), 3);	
		p_2dt_ens.(fn{1}) = nanmean(cat(3, p_2dti.(fn{1}){:}), 3);	
	end
	op_2d_ens = nanmean(cat(3, op_2d{:}), 3);
	amp_2d_ens = nanmean(cat(3, amp_2d{:}), 3);
	w500_2d_ens = nanmean(cat(3, c_2dti.w500{:}), 3);

	if strcmp(sim{1}, 'quad_all')
		c_ma_ens_amip = nanmean(c_ma_ens_amip, 1);
		p_ma_ens_amip = nanmean(p_ma_ens_amip, 1);
		pc_ma_ens_amip = nanmean(pc_ma_ens_amip, 1);
		c_ma_idx_ens_amip = nanmean(c_ma_idx_ens_amip, 1);
		p_ma_idx_ens_amip = nanmean(p_ma_idx_ens_amip, 1);
		pc_ma_idx_ens_amip = nanmean(pc_ma_idx_ens_amip, 1);
		c_ma_sub_ens_amip = nanmean(c_ma_sub_ens_amip, 1);
		p_ma_sub_ens_amip = nanmean(p_ma_sub_ens_amip, 1);
		pc_ma_sub_ens_amip = nanmean(pc_ma_sub_ens_amip, 1);

		c_ma_ens_aqua = nanmean(c_ma_ens_aqua, 1);
		p_ma_ens_aqua = nanmean(p_ma_ens_aqua, 1);
		pc_ma_ens_aqua = nanmean(pc_ma_ens_aqua, 1);
		c_ma_idx_ens_aqua = nanmean(c_ma_idx_ens_aqua, 1);
		p_ma_idx_ens_aqua = nanmean(p_ma_idx_ens_aqua, 1);
		pc_ma_idx_ens_aqua = nanmean(pc_ma_idx_ens_aqua, 1);
		c_ma_sub_ens_aqua = nanmean(c_ma_sub_ens_aqua, 1);
		p_ma_sub_ens_aqua = nanmean(p_ma_sub_ens_aqua, 1);
		pc_ma_sub_ens_aqua = nanmean(pc_ma_sub_ens_aqua, 1);

		for fn = fieldnames(p_2d)'
		    c_2d_ens_amip.(fn{1}) = nanmean(cat(2, c_2d_amip.(fn{1}){:}), 2);
		    c_2d_ens_aqua.(fn{1}) = nanmean(cat(2, c_2d_aqua.(fn{1}){:}), 2);
		    p_2d_ens_amip.(fn{1}) = nanmean(cat(2, p_2d_amip.(fn{1}){:}), 2);
		    p_2d_ens_aqua.(fn{1}) = nanmean(cat(2, p_2d_aqua.(fn{1}){:}), 2);
		end

		for fn = fieldnames(p_3d)'
		    c_3d_ens_amip.(fn{1}) = nanmean(cat(3, c_3di_amip.(fn{1}){:}), 3);
		    c_3d_ens_aqua.(fn{1}) = nanmean(cat(3, c_3di_aqua.(fn{1}){:}), 3);
		    p_3d_ens_amip.(fn{1}) = nanmean(cat(3, p_3di_amip.(fn{1}){:}), 3);
		    p_3d_ens_aqua.(fn{1}) = nanmean(cat(3, p_3di_aqua.(fn{1}){:}), 3);
		end

		for fn = fieldnames(p_2dt)'
			c_2dt_ens_amip.(fn{1}) = nanmean(cat(3, c_2dti_amip.(fn{1}){:}), 3);
			c_2dt_ens_aqua.(fn{1}) = nanmean(cat(3, c_2dti_aqua.(fn{1}){:}), 3);
			p_2dt_ens_amip.(fn{1}) = nanmean(cat(3, p_2dti_amip.(fn{1}){:}), 3);
			p_2dt_ens_aqua.(fn{1}) = nanmean(cat(3, p_2dti_aqua.(fn{1}){:}), 3);
		end
		op_2d_ens_amip = nanmean(cat(3, op_2d_amip{:}), 3);
		op_2d_ens_aqua = nanmean(cat(3, op_2d_aqua{:}), 3);
	end

	% tab = table(model, op_bulk);
	% writetable(tab, [par.localdir 'op.csv']);

	savename = ['./' data_path '/' type{1}, '_', sim{1}, sprintf('_eps_%g_%g_%g', par.pa_eps_lo/100, par.pa_eps_up/100, bnd)];
	if ~exist(savename, 'dir')
		mkdir(savename);
	end

	save(savename, 'amp_2d_ens', 'w500_2d_ens', 'amp', 'model', 'models', 'p_3d', 'c_3d', 'c_2d', 'p_2d', 'c_plev');

	if strcmp(type{1}, 'am2')
		if ~contains(sim{1}, {'BM', 'D'})
			p_alm_bulk(k, 1) = bulk_avg(p_3di.alm{k}, par.pa, par);
			c_alm_bulk(k, 1) = bulk_avg(c_3di.alm{k}, par.pa, par);
			save(savename, 'amp', 'model', 'models', 'p_alm_bulk', 'c_alm_bulk', 'p_3d', 'c_3d', 'p_plev', 'c_plev', 'p_2d', 'c_2d');
		else
			save(savename, 'amp', 'model', 'models', 'p_3d', 'c_3d', 'p_plev', 'c_plev', 'p_2d', 'c_2d');
		end
	end

end

end
