function [nanfilter2d, nanfilter3d, idx_mask, c_idx_x] = ascent_filter(nt, x_2d_lat, x_2d_lon, x_3d_lat, x_3d_plev, w500, type, sim, par, option) 

	% identify tropical bounds for masking out extratropics
	[~, idx_n] = min(abs(x_2d_lat - par.ta_bnd));
        [~, idx_s] = min(abs(x_2d_lat + par.ta_bnd));

	% create lat x lon grid that corresponds to land mask
	[lat2dgrid, lon2dgrid] = meshgrid(x_2d_lat, x_2d_lon-180);

	% Use upper x as threshold
	if ~strcmp(type{1}, 'am2') & ~strcmp(sim{1}, 'aqua') & strcmp(option, 'land')
		land_mask =~ circshift(landmask(lat2dgrid, lon2dgrid), length(x_2d_lon)/2, 1);
		land_mask = double(land_mask);
		% mask out land
		land_mask(land_mask == 0) = nan;

		if strcmp(option, 'resolve_t')
			land_mask = repmat(land_mask, [1 1 nt]);
		end

		w500_pos = w500 .* land_mask;
		w500_idx = w500 .* land_mask;
	else
		w500_pos = w500;
		w500_idx = w500;
	end
	% mask out extratropics as well
	et_mask = nan(size(w500));
	et_mask(:,idx_s:idx_n) = 1;
	w500_pos = w500_pos.*et_mask;	
	w500_idx = w500_idx.*et_mask;

	w500_pos_vec = w500_pos(:);
	id_pos = find(w500_pos_vec(:)>=0);
	w500_pos_vec(id_pos) = [];
	if contains(sim{1}, '_uni')
		c_idx_x= prctile(-w500_pos_vec, par.idx_perc);
	else
		c_idx_x= par.w_thresh * 100 / (3600 * 24); %prctile(-w500_pos_vec, par.idx_perc);
	end
	w500_idx(w500>=-c_idx_x)=nan;
	idx_mask =~ isnan(w500_idx);
	idx_mask = double(idx_mask);
	if ~strcmp(option, 'resolve_t')
		w500_idx = repmat(w500_idx, [1 1 nt]);
	end

	% w convection filtered values
	nanfilter2d =~ isnan(w500_idx);
	nanfilter2d = double(nanfilter2d);
	nanfilter2d(nanfilter2d == 0) = nan;

	nanfilter3d = permute(nanfilter2d, [2 1 3]);
	nanfilter3d = interp1(x_2d_lat, nanfilter3d, x_3d_lat);
	nanfilter3d = permute(nanfilter3d, [2 1 3]);
	nanfilter3d = repmat(nanfilter3d, [1, 1, 1, length(x_3d_plev)]);
	nanfilter3d = permute(nanfilter3d, [1 2 4 3]);

end
