function pa_trop = calc_tpause(ta, plev, par)

	if all(isnan(ta))

		pa_trop = nan;

	else

		% compute lapse rate in p and z coord.
		phalf = 1/2 * (plev(2:end) + plev(1:end-1));
		dtadpa_half = (ta(2:end)-ta(1:end-1))./(plev(2:end)-plev(1:end-1));
		dtadpa = interp1(phalf, dtadpa_half, plev);
		dtadz = dtadpa .* (-plev*par.g)./(par.Rd*ta);	
		Gamma0 = -dtadz;
		Gamma0 = fillmissing(Gamma0, 'nearest');
		% interpolate Gamma profile to more resolute pressure grid
		Gamma = interp1(plev, Gamma0, par.pa_ptrop, 'pchip');

		% identify tropopause according to WMO definition (lowest level where Gamma < 2 K/km)
		% first get a ballpark of where the tropopause is in native grid
		pa_trop0 = max(par.pa_ptrop(Gamma<0.002 & par.pa_ptrop<50000));
		% identify index of this rough tropopause
		[~,id_ptrop] = min(abs(par.pa_ptrop - pa_trop0));
		% interpolate around this level to more precisely calculate tropopause pressure
		pa_trop = interp1(Gamma(id_ptrop-1:id_ptrop+1), par.pa_ptrop(id_ptrop-1:id_ptrop+1), 0.002);

	end
end
