function [ta_s, eps, eps_z, eps_r, eps_r_z, eps_rh, eps_rh_z, rh_r, pa_trop] = comp_ma(ta, hur, plev, ts, hs, ps, par)

	if all(isnan(ta))
		
		ta_s = nan(size(ta));
		eps = nan(size(ta));
		eps_z = nan(size(ta));
		eps_r = nan(size(ta));
		eps_r_z = nan(size(ta));
		eps_rh = nan(size(ta));
		eps_rh_z = nan(size(ta));
		rh_r = nan(size(ta));
		pa_trop = nan;

	else

		if size(ta, 1) > size(ta, 2)
			ta = ta';
		end

		if size(hur, 1) > size(hur, 2)
			hur = hur';
		end

		if size(plev, 1) > size(plev, 2)
			plev = plev';
		end

		% calculate tropopause height
		pa_trop = calc_tpause(ta, plev, par);

		% integrate temperature profiles over height
		dpa = -10;

		pa_cd(1) = ps;
		ta_cd(1) = ts;
		esat_cd(1) = calc_esat(ta_cd(1), par.frz);
		qsat_cd(1) = calc_q(pa_cd(1), esat_cd(1), par);
		rh(1) = hs / 100;
		r(1) = par.eps * rh(1) * esat_cd(1) / (pa_cd(1) - rh(1) * esat_cd(1));
		deriv_dry(1) = dry(pa_cd(1), ta_cd(1), par);
		[pa_d, ta_pa_d]=ode45(@(pa, T) dry(pa, T, par), par.pa_span, ta_cd(1));
		i = 2;
		while rh(i-1) < 1
		    idx_lcl = i;
		    pa_cd(i) = pa_cd(i-1) + dpa;
		    ta_cd(i, 1) = ta_cd(i-1) + dpa * deriv_dry(i-1);
		    esat_cd(i, 1) = calc_esat(ta_cd(i), par.frz);
		    qsat_cd(i, 1) = calc_q(pa_cd(i), esat_cd(i), par);
		    r(i, 1) = r(i-1);
		    rh(i, 1) = r(i) * pa_cd(i) / (esat_cd(i) * (r(i) + par.eps));
		    deriv_dry(i, 1) = dry(pa_cd(i), ta_cd(i), par);
		    i = i + 1;
		end
		pa_lcl = pa_cd(end);
		if par.reversible
			par.r_t = r(end); % moisture at LCL is the total moisture of rising parcel
			[pa_cs, ta_cs] = ode45(@(pa, T) sat_rev(pa, T, par.frz, par), [pa_lcl, par.pa_span(end)], ta_cd(end));
		else
			[pa_cs, ta_cs] = ode45(@(pa, T) sat(pa, T, par.frz, par), [pa_lcl, par.pa_span(end)], ta_cd(end));
		end
		for i = 1:length(pa_cs)
			if par.reversible
			    [deriv_cs(i, 1), qsat_cs(i, 1)] = sat_rev(pa_cs(i), ta_cs(i), par.frz, par);
			else
			    [deriv_cs(i, 1), qsat_cs(i, 1)] = sat(pa_cs(i), ta_cs(i), par.frz, par);
			end
		    deriv_csd(i, 1) = dry(pa_cs(i), ta_cs(i), par);
		end
		ta_s(:, 1) = [ta_cd; ta_cs(2:end)];
		pa_s(:, 1) = [pa_cd(:); pa_cs(2:end)];
		qsat_s(:, 1) = [qsat_cd(:, 1); qsat_cs(2:end)];
		dtadpa_s(:, 1) = [deriv_dry; deriv_cs(2:end)];

		ta_s = interp1(pa_s, ta_s, plev, 'linear', 'extrap');
		qsat_s = interp1(pa_s, qsat_s, plev, 'linear', 'extrap');
		dtadpa_s = interp1(pa_s, dtadpa_s, plev, 'linear', 'extrap');

		dtadpa = comp_dtadpa(ta, plev);
		dtadpa_d = par.Rd * ta ./ (par.cpd * plev);

		% calculate moisture and thermo variables for actual temp
		for lev = 1:length(plev)
			esat(lev) = calc_esat(ta(lev), par.frz);
			qsat(lev) = calc_q(plev(lev), esat(lev), par);
			L_vec(lev) = calc_L(ta(lev));
		end

		% calculate fractional lapse rate gamma
		gamma = L_vec .* dtadpa ./ (par.Rv * ta.^2) - 1./plev;
		gamma_s = L_vec .* dtadpa_s ./ (par.Rv * ta_s.^2) - 1./plev;

		% calculate Romps entrainment
		[a_const, bet] = deal(nan(size(plev)));
		a_const = (dtadpa_d .* (1 + (L_vec .* qsat) ./ (par.Rd * ta) ) - dtadpa .* ( 1 + (L_vec.^2 .* qsat)./ (par.cpd * par.Rv * ta.^2) ) ) ./ (dtadpa - dtadpa_d);
		bet = a_const .* gamma;
		eps_r = bet / par.pe;
		eps_r_z = eps_r .* plev * par.g ./ (par.Rd .* ta);
		rh_r = (a_const + par.pe) ./ (a_const + 1);

		% calculate bulk-plume entrainment
		eps_bp = nan(size(plev));
		eps_bp = (par.cpd * dtadpa + L_vec .* qsat .* gamma - (par.Rd * ta) ./ plev) ./ (par.cpd*(ta_s - ta) + L_vec .* qsat .* (1 - hur/100));
		eps_bp_z = eps_bp .* plev * par.g ./ (par.Rd .* ta_s);

		% calculate Singh and O'Gorman entrainment
		eps = nan(size(plev));
		eps = (par.cpd * dtadpa + L_vec .* qsat .* gamma - (par.Rd * ta) ./ plev) ./ (L_vec .* qsat .* (1 - hur/100));
		eps_z = eps .* plev * par.g ./ (par.Rd .* ta);

		% calculate Singh and O'Gorman entrainment with Romps RH 
		eps_rh = nan(size(plev));
		eps_rh = (par.cpd * dtadpa + L_vec .* qsat .* gamma - (par.Rd * ta) ./ plev) ./ (L_vec .* qsat .* (1 - rh_r));
		eps_rh_z = eps_rh .* plev * par.g ./ (par.Rd .* ta);

	end

end
