function net_eps = comp_net_eps(ta, wap, plev, lat3d, par)

	% take time mean of wap
	ta = tmean(ta);
	wap = tmean(wap);

	% repeat pressure at all grid points
	pa = repmat(plev, [1, size(wap, 1), size(wap, 2)]);
	pa = permute(pa, [2 3 1]);

	% calculate mass flux (in kg/m^2/s)
	mc = - wap / par.g;

	% calculate vertical derivative of mass flux (in pressure)
	plev_half = 1/2 * (plev(2:end) + plev(1:end-1));
	dmcdpa_half = ( mc(:, :, 2:end) - mc(:, :, 1:end-1) ) ./ ( pa(:, :, 2:end) - pa(:, :, 1:end-1) );
	dmcdpa_half = permute(dmcdpa_half, [3 1 2]);
	dmcdpa = interp1(plev_half, dmcdpa_half, plev);
	dmcdpa = permute(dmcdpa, [2 3 1]);

	% convert vertical derivative to z
	dmcdz = - dmcdpa .* pa * par.g ./ (par.Rd * ta);	

	% calculate net large scale entrainment
	net_eps = dmcdz ./ mc;

end
