function [ta_s, ta_e, eps, eps_alt] = comp_romps(ts, hs, ps, a, par)

		% integrate temperature profiles over height
		dpa = -10;

		pa_cd(1) = ps;
		ta_cd(1) = ts;
		esat_cd(1) = calc_esat(ta_cd(1), par.frz);
		qsat_cd(1) = calc_q(pa_cd(1), esat_cd(1), par);
		rh(1) = hs / 100;
		r(1) = par.eps * rh(1) * esat_cd(1) / (pa_cd(1) - rh(1) * esat_cd(1));
		deriv_dry(1) = dry(pa_cd(1), ta_cd(1), par);
		[pa_d, ta_pa_d]=ode45(@(pa, T) dry(pa, T, par), par.pa_span, ta_cd(1));
		i = 2;
		while rh(i-1) < 1
		    idx_lcl = i;
		    pa_cd(i) = pa_cd(i-1) + dpa;
		    ta_cd(i, 1) = ta_cd(i-1) + dpa * deriv_dry(i-1);
		    esat_cd(i, 1) = calc_esat(ta_cd(i), par.frz);
		    qsat_cd(i, 1) = calc_q(pa_cd(i), esat_cd(i), par);
		    r(i, 1) = r(i-1);
		    rh(i, 1) = r(i) * pa_cd(i) / (esat_cd(i) * (r(i) + par.eps));
		    deriv_dry(i, 1) = dry(pa_cd(i), ta_cd(i), par);
		    i = i + 1;
		end
		pa_lcl = pa_cd(end);
		if par.reversible
			par.r_t = r(end); % moisture at LCL is the total moisture of rising parcel
			[pa_cs, ta_cs] = ode45(@(pa, T) sat_rev(pa, T, par.frz, par), [pa_lcl, par.pa_span(end)], ta_cd(end));
			[pa_ce, ta_ce] = ode45(@(pa, T) sat_romps(pa, T, a, par.frz, par), [pa_lcl, par.pa_span(end)], ta_cd(end));
		else
			[pa_cs, ta_cs] = ode45(@(pa, T) sat(pa, T, par.frz, par), [pa_lcl, par.pa_span(end)], ta_cd(end));
			[pa_ce, ta_ce] = ode45(@(pa, T) sat_romps(pa, T, a, par.frz, par), [pa_lcl, par.pa_span(end)], ta_cd(end));
		end
		for i = 1:length(pa_cs)
			if par.reversible
			    [deriv_cs(i, 1), qsat_cs(i, 1)] = sat_rev(pa_cs(i), ta_cs(i), par.frz, par);
			else
			    [deriv_cs(i, 1), qsat_cs(i, 1)] = sat(pa_cs(i), ta_cs(i), par.frz, par);
			end
		    deriv_csd(i, 1) = dry(pa_cs(i), ta_cs(i), par);
		end
		for i = 1:length(pa_ce)
			if par.reversible
			    [deriv_ce(i, 1), qsat_ce(i, 1)] = sat_romps(pa_ce(i), ta_ce(i), a, par.frz, par);
			else
			    [deriv_ce(i, 1), qsat_ce(i, 1)] = sat_romps(pa_ce(i), ta_ce(i), a, par.frz, par);
			end
		    deriv_ced(i, 1) = dry(pa_ce(i), ta_ce(i), par);
		end
		ta_s(:, 1) = [ta_cd; ta_cs(2:end)];
		ta_e(:, 1) = [ta_cd; ta_ce(2:end)];
		pa_s(:, 1) = [pa_cd(:); pa_cs(2:end)];
		pa_e(:, 1) = [pa_cd(:); pa_ce(2:end)];
		qsat_s(:, 1) = [qsat_cd(:, 1); qsat_cs(2:end)];
		qsat_e(:, 1) = [qsat_cd(:, 1); qsat_ce(2:end)];
		dtadpa_s(:, 1) = [deriv_dry; deriv_cs(2:end)];
		dtadpa_e(:, 1) = [deriv_dry; deriv_ce(2:end)];

		ta_s = interp1(pa_s, ta_s, par.plev, 'linear', 'extrap');
		ta_e = interp1(pa_e, ta_e, par.plev, 'linear', 'extrap');
		qsat_s = interp1(pa_s, qsat_s, par.plev, 'linear', 'extrap');
		qsat_e = interp1(pa_e, qsat_e, par.plev, 'linear', 'extrap');
		dtadpa_s = interp1(pa_s, dtadpa_s, par.plev, 'linear', 'extrap');
		dtadpa_e = interp1(pa_e, dtadpa_e, par.plev, 'linear', 'extrap');

		for lev = 1:length(par.plev)
			L_s(lev) = calc_L(ta_s(lev));
			L_e(lev) = calc_L(ta_e(lev));
		end
		% calculate fractional lapse rate gamma
		gamma_s = L_s .* dtadpa_s ./ (par.Rv * ta_s.^2) - 1./par.plev;
		gamma_e = L_e .* dtadpa_e ./ (par.Rv * ta_e.^2) - 1./par.plev;
		
		% alternate calculation of fractional lapse rate
		par.plev_h = (par.plev(2:end)+par.plev(1:end-1))/2;
		par.dplev_h = par.plev(2:end)-par.plev(1:end-1);
		dqdpa_s = (qsat_s(2:end)-qsat_s(1:end-1))./par.dplev_h;
		dqdpa_e = (qsat_e(2:end)-qsat_e(1:end-1))./par.dplev_h;
		dqdpa_s = interp1(par.plev_h, dqdpa_s, par.plev);
		dqdpa_e = interp1(par.plev_h, dqdpa_e, par.plev);
		gamma_s_alt = dqdpa_s./qsat_s;
		gamma_e_alt = dqdpa_e./qsat_e;

		% entrainment
		eps = a*gamma_e/par.pe;
		eps_alt = a*gamma_e_alt/par.pe;
end
