function [ta_s, ta_e, pa_s, pa_e, rh_s, rh_e] = comp_romps_z(ts, hs, ps, eps, par)

		% integrate temperature profiles over height
		dz = 100;

		z_cd(1) = par.z_span(1);
		pa_cd(1) = ps;
		ta_cd(1) = ts;
		esat_cd(1) = calc_esat(ta_cd(1), par.frz);
		qsat_cd(1) = calc_q(pa_cd(1), esat_cd(1), par);
		rh(1) = hs / 100;
		r(1) = par.eps * rh(1) * esat_cd(1) / (pa_cd(1) - rh(1) * esat_cd(1));
		dtdz_dpdz(1,:) = dry_z([ta_cd(1), pa_cd(1)], par);
		T_p0 = [ta_cd(1), pa_cd(1)];
		[z_d, ta_pa_d]=ode45(@(z, T_p) dry_z(T_p, par), par.z_span, T_p0);
		i = 2;
		while rh(i-1) < 1
		    idx_lcl = i;
			z_cd(i, 1) = z_cd(i-1) + dz;
			pa_cd(i, 1) = pa_cd(i-1) + dz * dtdz_dpdz(i-1, 2);
			ta_cd(i, 1) = ta_cd(i-1) + dz * dtdz_dpdz(i-1, 1);
			esat_cd(i, 1) = calc_esat(ta_cd(i), par.frz);
			qsat_cd(i, 1) = calc_q(pa_cd(i), esat_cd(i), par);
			r(i, 1) = r(i-1);
			rh(i, 1) = r(i) * pa_cd(i) / (esat_cd(i) * (r(i) + par.eps));
			dtdz_dpdz(i,:) = dry_z([ta_cd(i), pa_cd(i)], par);
			i = i + 1;
		end
		z_lcl = z_cd(end);
		pa_lcl = pa_cd(end);
		ta_pa_cd = [ta_cd, pa_cd];
		deriv_dry(:,1) = dtdz_dpdz(:,1);
		if par.reversible
			par.r_t = r(end); % moisture at LCL is the total moisture of rising parcel
			[z_cs, ta_pa_cs] = ode45(@(z, T_p) sat_rev_z(T_p, par.frz, par), [z_lcl, par.z_span(end)], ta_pa_cd(end,:));
			h1 = interp1(ta_pa_cs(:,1), z_cs, 240); % middle of troposphere
			[z_ce, ta_pa_ce] = ode45(@(z, T_p) sat_romps_z(z, T_p, eps, par.frz, h1, par), [z_lcl, par.z_span(end)], ta_pa_cd(end,:));
		else
			[z_cs, ta_pa_cs] = ode45(@(z, T_p) sat_z(T_p, par.frz, par), [z_lcl, par.z_span(end)], ta_pa_cd(end,:));
			h1 = interp1(ta_pa_cs(:,1), z_cs, 240); % middle of troposphere
			[z_ce, ta_pa_ce] = ode45(@(z, T_p) sat_romps_z(z, T_p, eps, par.frz, h1, par), [z_lcl, par.z_span(end)], ta_pa_cd(end,:));
		end
		for i = 1:length(z_cs)
			if par.reversible
			    [dt_dp_cs(i, :), qsat_cs(i, 1)] = sat_rev_z(ta_pa_cs(i,:), par.frz, par);
			else
			    [dt_dp_cs(i, :), qsat_cs(i, 1)] = sat_z(ta_pa_cs(i,:), par.frz, par);
			end
		    dt_dp_csd(i, :) = dry_z([ta_pa_cs(i,:)], par);
		end
		for i = 1:length(z_ce)
			if par.reversible
			    [dt_dp_ce(i, :), qsat_ce(i, 1), rh_ce(i,1)] = sat_romps_z(z_ce(i), ta_pa_ce(i,:), eps, par.frz, h1, par);
			else
			    [dt_dp_ce(i, :), qsat_ce(i, 1), rh_ce(i,1)] = sat_romps_z(z_ce(i), ta_pa_ce(i,:), eps, par.frz, h1, par);
			end
		    dt_dp_ced(i, :) = dry_z([ta_pa_ce(i,:)], par);
		end
			deriv_cs(:,1) = dt_dp_cs(:,1);
			deriv_ce(:,1) = dt_dp_ce(:,1);
			deriv_csd(:,1) = dt_dp_csd(:,1);
			deriv_ced(:,1) = dt_dp_ced(:,1);
		z_s(:, 1) = [z_cd; z_cs(2:end)];
		z_e(:, 1) = [z_cd; z_ce(2:end)];
		rh_s(:, 1) = [rh; ones(size(rh_ce(2:end)))];
		rh_e(:, 1) = [rh; rh_ce(2:end)];
		ta_s(:, 1) = [ta_cd; ta_pa_cs(2:end,1)];
		ta_e(:, 1) = [ta_cd; ta_pa_ce(2:end,1)];
		pa_s(:, 1) = [pa_cd(:); ta_pa_cs(2:end,2)];
		pa_e(:, 1) = [pa_cd(:); ta_pa_ce(2:end,2)];
		qsat_s(:, 1) = [qsat_cd(:, 1); qsat_cs(2:end)];
		qsat_e(:, 1) = [qsat_cd(:, 1); qsat_ce(2:end)];
		dtadz_s(:, 1) = [deriv_dry; deriv_cs(2:end)];
		dtadz_e(:, 1) = [deriv_dry; deriv_ce(2:end)];

		rh_s = interp1(z_s, rh_s, par.z, 'linear', 'extrap');
		rh_e = interp1(z_e, rh_e, par.z, 'linear', 'extrap');
		pa_s = interp1(z_s, pa_s, par.z, 'linear', 'extrap');
		pa_e = interp1(z_e, pa_e, par.z, 'linear', 'extrap');
		ta_s = interp1(z_s, ta_s, par.z, 'linear', 'extrap');
		ta_e = interp1(z_e, ta_e, par.z, 'linear', 'extrap');
		qsat_s = interp1(z_s, qsat_s, par.z, 'linear', 'extrap');
		qsat_e = interp1(z_e, qsat_e, par.z, 'linear', 'extrap');
		dtadz_s = interp1(z_s, dtadz_s, par.z, 'linear', 'extrap');
		dtadz_e = interp1(z_e, dtadz_e, par.z, 'linear', 'extrap');

		for lev = 1:length(par.z)
			L_s(lev) = calc_L(ta_s(lev));
			L_e(lev) = calc_L(ta_e(lev));
		end

end
