function [ta_s, eps, eps_z, eps_r, eps_r_z, eps_rh, eps_rh_z, rh_r, ts, hs, pa_trop] = comp_ta_s(id_model, ta_in, hur_in, x_2d_orig, x_2dt, plev, lat2d, lon2d, lat3d, par, model, nanfilter2d, do_idx, option)

	n_lon = size(ta_in,1);
	n_lat = size(ta_in,2);
	n_time = size(ta_in,4);

	if strcmp(option, 'resolve_t')
	% take zonal mean, meridional mean of variables
		if do_idx
			ps_temp = squeeze(nanmean(x_2d_orig.ps.*nanfilter2d, 1));
		else
			ps_temp = squeeze(nanmean(x_2d_orig.ps, 1));
		end
		ta_temp = squeeze(nanmean(ta_in, 1));
		hur_temp = squeeze(nanmean(hur_in, 1));
		ps_temp = interp1( lat2d, ps_temp, par.lat );
		ta_temp = interp1( lat3d, ta_temp, par.lat );
		hur_temp = interp1( lat3d, hur_temp, par.lat );
		for id_t = 1:n_time
			ps(id_t) = areamean( ps_temp(:,id_t), par );
			ta(:,id_t) = areamean( ta_temp(:,:,id_t), par, plev );
			hur(:,id_t) = areamean( hur_temp(:,:,id_t), par, plev );
		end
	else
	% take time mean of all variables
		ta = tmean(ta_in);
		hur = tmean(hur_in);
		ps = x_2dt.ps{id_model};
	end

	% interpolate ps onto 3d lat grid
	if ~strcmp(option, 'resolve_t')
		ps = permute(ps, [2 1]);
		ps = interp1(lat2d, ps, lat3d);
		ps = permute(ps, [2 1]);
	end
	
	if strcmp(option, 'nonsurf')
		ps(:,:) = par.ma_init;
	end

	% load tas and hurs if available
	if strcmp(option, 'resolve_t')
		if any(contains(fieldnames(x_2d_orig), 'tas'))
			if do_idx
				tas_temp = squeeze( nanmean( x_2d_orig.tas.*nanfilter2d, 1) );
			else
				tas_temp = squeeze( nanmean( x_2d_orig.tas, 1) );
			end
			tas_temp = interp1( lat2d, tas_temp, par.lat );
			for id_t = 1:n_time
				tas(id_t) = areamean( tas_temp(:,id_t), par );
			end
		end

		if any(contains(fieldnames(x_2d_orig), 'hurs'))
			if do_idx
				hurs_temp = squeeze( nanmean( x_2d_orig.hurs.*nanfilter2d, 1) );
			else
				hurs_temp = squeeze( nanmean( x_2d_orig.hurs, 1) );
			end
			hurs_temp = interp1( lat2d, hurs_temp, par.lat );
			for id_t = 1:n_time
				hurs(id_t) = areamean( hurs_temp(:,id_t), par );
			end
		end
	else
		if any(contains(fieldnames(x_2d_orig), 'tas'))
			tas = x_2dt.tas{id_model};
			tas = permute(tas, [2 1]);
			tas = interp1(lat2d, tas, lat3d);
			tas = permute(tas, [2 1]);
		end

		if any(contains(fieldnames(x_2d_orig), 'hurs'))
			hurs = x_2dt.hurs{id_model};
			hurs = permute(hurs, [2 1]);
			hurs = interp1(lat2d, hurs, lat3d);
			hurs = permute(hurs, [2 1]);
		end
	end

	% calculate moist adiabat
	if ~strcmp(option, 'resolve_t')
		ta = permute(ta, [3 1 2]);
		hur = permute(hur, [3 1 2]);
	end

	pb = CmdLineProgressBar('Calculating moist adiabats...');
	
	if strcmp(option, 'resolve_t')
		[ta_s, eps, eps_z, eps_r, eps_r_z, eps_rh, eps_rh_z] = deal(nan([size(ta)]));
		[pa_trop, ts, hs] = deal(nan([length(ps) 1]));
	else
		[ta_s, eps, eps_z, eps_r, eps_r_z, eps_rh, eps_rh_z, pa_trop] = deal(nan([size(ta, 2), size(ta, 3), length(plev)]));
		pa_trop = nan([size(ta,2), size(ta,3)]);
	end
	
	if strcmp(option, 'resolve_t')
		% loop through time
		for k = 1:n_time
			pb.print(k, n_time);

			if any(contains(fieldnames(x_2d_orig), 'tas')) & ~strcmp(option, 'use_ps') & ~strcmp(option, 'nonsurf')
				ts(k,1) = tas(k);
			else
				ta_fill = fillmissing(ta(:,k), 'linear', 'endvalues', 'nearest');
				ts(k,1) = interp1(plev, ta_fill, ps(k), 'linear', 'extrap');
			end
			
			if any(contains(fieldnames(x_2d_orig), 'hurs')) & ~strcmp(option, 'use_ps') & ~strcmp(option, 'nonsurf')
				hs(k,1) = hurs(k);
			else
				hur_fill = fillmissing(hur(:,k), 'linear', 'endvalues', 'nearest');
				hs(k,1) = interp1(plev, hur_fill, ps(k), 'linear', 'extrap');
			end

			[ta_s(:,k), eps(:,k), eps_z(:,k), eps_r(:,k), eps_r_z(:,k), eps_rh(:,k), eps_rh_z(:,k), rh_r(:,k), pa_trop(k,1)] = comp_ma(ta(:,k), hur(:,k), plev, ts(k), hs(k), ps(k), par);

		end

	else
		% loop through lon
		for i = 1:n_lon;
			pb.print(i, n_lon);

			% loop through lat
			for j = 1:n_lat;
			
				if any(contains(fieldnames(x_2d_orig), 'tas')) & ~strcmp(option, 'use_ps') & ~strcmp(option, 'nonsurf')
					ts(i,j) = tas(i,j);
				else
					ta_fill = fillmissing(ta(:, i, j), 'linear', 'endvalues', 'nearest');
					ts(i,j) = interp1(plev, ta_fill, ps(i, j), 'linear', 'extrap');
				end
				
				if any(contains(fieldnames(x_2d_orig), 'hurs')) & ~strcmp(option, 'use_ps')
					hs(i,j) = hurs(i,j);
				else
					hur_fill = fillmissing(hur(:, i, j), 'linear', 'endvalues', 'nearest');
					hs(i,j) = interp1(plev, hur_fill, ps(i, j), 'linear', 'extrap');
				end

				[ta_s(i, j, :), eps(i, j, :), eps_z(i, j, :), eps_r(i, j, :), eps_r_z(i, j, :), eps_rh(i,j,:), eps_rh_z(i,j,:), rh_r(i,j,:), pa_trop(i,j)] = comp_ma(ta(:, i, j), hur(:, i, j), plev, ts(i,j), hs(i,j), ps(i,j), par);

			end
			% lat loop

		end
		% lon loop
	end

	if strcmp(option, 'resolve_t')
		ta_s = repmat(ta_s, [1 1 n_lon n_lat]); 
		ta_s = permute(ta_s, [3 4 1 2]);
		eps = repmat(eps, [1 1 n_lon n_lat]); 
		eps = permute(eps, [3 4 1 2]);
		eps_z = repmat(eps_z, [1 1 n_lon n_lat]); 
		eps_z = permute(eps_z, [3 4 1 2]);
		eps_r = repmat(eps_r, [1 1 n_lon n_lat]); 
		eps_r = permute(eps_r, [3 4 1 2]);
		eps_r_z = repmat(eps_r_z, [1 1 n_lon n_lat]); 
		eps_r_z = permute(eps_r_z, [3 4 1 2]);
		eps_rh = repmat(eps_rh, [1 1 n_lon n_lat]); 
		eps_rh = permute(eps_rh, [3 4 1 2]);
		eps_rh_z = repmat(eps_rh_z, [1 1 n_lon n_lat]); 
		eps_rh_z = permute(eps_rh_z, [3 4 1 2]);
		rh_r = repmat(rh_r, [1 1 n_lon n_lat]); 
		rh_r = permute(rh_r, [3 4 1 2]);
		pa_trop = repmat(pa_trop, [1 n_lon n_lat]); 
		pa_trop = permute(pa_trop, [2 3 1]);
		ts = repmat(ts, [1 n_lon n_lat]); 
		ts = permute(ts, [2 3 1]); 
		hs = repmat(hs, [1 n_lon n_lat]); 
		hs = permute(hs, [2 3 1]); 

	end

end
