function eps = comp_zx_eps(T, RH, z, pa, Tb, RHb, pab, par)
	% calculate epsilon following spectral plume model of Zhou and Xie (2019)

	eps = nan(size(T)); % initialize empty epsilon profile

	% calculate vertical profiles of necessary variables
	for i=1:length(T)
		L(i) = calc_L(T(i), par.frz);
		qsat(i) = calc_q(pa(i), calc_esat(T(i), par.frz), par);
		h(i) = par.cpd*T(i) + par.g*z(i) + qsat(i)*RH(i)/100*L(i);
		hsat(i) = par.cpd*T(i) + par.g*z(i) + qsat(i)*L(i);
	end
	% calculate necessary surface values
	Lb = calc_L(Tb, par.frz);
	qsatb = calc_q(pab, calc_esat(Tb, par.frz), par);
	hb = par.cpd*Tb + qsatb*RHb/100*Lb;

	hdef = hsat - hb;
	z_half = 1/2*(z(2:end) + z(1:end-1));
	dhdefdz_half = (hdef(2:end) - hdef(1:end-1)) ./ (z(2:end) - z(1:end-1)); 
	dhdefdz = interp1(z_half, dhdefdz_half, z, 'pchip');

		figure(); clf; hold all;
		plot((hsat-hb)/par.cpd, z/1000, '-r');
		plot((h-hb)/par.cpd, z/1000, '-b');
		set(gca, 'ylim', [0 15], 'xlim', [-inf, 0])
		vline(0, '-k'); hline(12, '-k');
		printname = './figs_zx/hdef';
		print(printname, '-dpng', '-r300');

		figure(); clf; hold all;
		plot(dhdefdz, z/1000, '-k');
		set(gca, 'ylim', [0 15])
		vline(0, '-k'); hline(12, '-k');
		printname = './figs_zx/dhdefdz';
		print(printname, '-dpng', '-r300');

	% cloud top height as where env MSE* = moist adb MSE
	par.z_span = 1e3*linspace(0, 20, 100);
	[~, id_tplow] = min(abs(z-10e3));
	[~, id_tphigh] = min(abs(z-20e3));
	zt = interp1(hsat(id_tplow:id_tphigh)-hb, z(id_tplow:id_tphigh), 0);
	% cloud base height
	zb = comp_lcl_z(Tb, RHb, pab, par);

	% integrate down from cloud top
	dz = 5;
	ze = zb:dz:zt;
	eta = 0.75;
	pae = interp1(z, pa, ze);
	he = interp1(z, h, ze);
	hesat = interp1(z, hsat, ze);
	hdefe = interp1(z, hdef, ze);
	dhdefdze = interp1(z, dhdefdz, ze);
	Le = interp1(z, L, ze);
	qesat = interp1(z, qsat, ze);
	RHe = interp1(z, RH, ze);
	epse = nan(size(ze));
	epse(end) = 0;
	epsp = nan(size(ze));
	epsp(end) = 0;

	for i=length(ze)-1:-1:1
		%fx = @(x) (hdefe(i+1)-hdefe(i))/dz-1./(1+eta*x*(ze(i)-zb)).*(length(ze)-i+1)./((length(ze)-i)*epse(i+1)+x).*(-x)/(dz)*hdefe(i) + x*(1-RHe(i)/100)*Le(i)*qesat(i);
		fx = @(x) dhdefdze(i)-1./(1+eta*x*(ze(i)-zb)).*(length(ze)-i+1)./((length(ze)-i)*epse(i+1)+x).*(-x)/(dz)*hdefe(i) + x*(1-RHe(i)/100)*Le(i)*qesat(i);
		% fx = @(x) dhdefdze(i+1)-1./(1+eta*x*(ze(i+1)-zb)).*(length(ze)-i+1)./((length(ze)-i)*epse(i+1)+x).*(-x)/(dz)*hdefe(i+1) + x*(1-RHe(i+1)/100)*Le(i+1)*qesat(i+1);
		% fx = @(x) (hdefe(i+1)-hdefe(i))/(dz)-1./(1+eta*epsp(i+1)*(ze(i+1)-zb)).*(length(ze)-i+1)./((length(ze)-i)*epse(i+1)+x).*(-x)/(dz)*hdefe(i+1) + epsp(i+1)*(1-RHe(i+1)/100)*Le(i+1)*qesat(i+1);
		options = optimset('TolX', 1e-9);
		epsp(i) = bisection(fx, 1e-4, 1e-2, 0, options);
		epse(i) = nanmean(epsp(i:end));
	end

		figure(); clf; hold all;
		plot(epse, pae/1e2);
		set(gca, 'ydir', 'reverse', 'yscale', 'log');
		printname = './figs_zx/eps';
		print(printname, '-dpng', '-r300');

end
