function [ta_s, ta_e, pa_s, pa_e, eps_z] = comp_zx_z(ts, hs, ps, eps0, par)

		% integrate temperature profiles over height
		dz = 100;

		z_cd(1) = par.z_span(1);
		pa_cd(1) = ps;
		ta_cd(1) = ts;
		rh(1) = hs / 100;
		esat_cd(1) = calc_esat(ta_cd(1), par.frz);
		qsat_cd(1) = calc_q(pa_cd(1), esat_cd(1), par);
		r(1) = par.eps * rh(1) * esat_cd(1) / (pa_cd(1) - rh(1) * esat_cd(1));
		h_b = ts + qsat_cd(1)*rh(1)*calc_L(ts, par.frz)/par.cpd;
		dtdz_dpdz(1,:) = dry_z([ta_cd(1), pa_cd(1)], par);
		T_p0 = [ta_cd(1), pa_cd(1)];
		[z_d, ta_pa_d]=ode45(@(z, T_p) dry_z(T_p, par), par.z_span, T_p0);
		i = 2;
		while rh(i-1) < 1
		    idx_lcl = i;
			z_cd(i, 1) = z_cd(i-1) + dz;
			pa_cd(i, 1) = pa_cd(i-1) + dz * dtdz_dpdz(i-1, 2);
			ta_cd(i, 1) = ta_cd(i-1) + dz * dtdz_dpdz(i-1, 1);
			esat_cd(i, 1) = calc_esat(ta_cd(i), par.frz);
			qsat_cd(i, 1) = calc_q(pa_cd(i), esat_cd(i), par);
			r(i, 1) = r(i-1);
			rh(i, 1) = r(i) * pa_cd(i) / (esat_cd(i) * (r(i) + par.eps));
			dtdz_dpdz(i,:) = dry_z([ta_cd(i), pa_cd(i)], par);
			i = i + 1;
		end
		z_lcl = z_cd(end);
		pa_lcl = pa_cd(end);
		z_t = par.cpd/par.g*(h_b-0.84*255); %prediction of cloud top following Zhou and Xie (2019)
		dz = 20;
		ze = z_lcl:dz:z_t; % make fine grid for calculating entrainment profile
		eps_p = eps0 * ( (z_t - ze)/(z_t-z_lcl) ).^par.k; % entrainment rate per each plume
		for lev = 1:length(ze)
			eps(lev) = nanmean(eps_p(lev:end)); % actual entrainment rate (bulk average of all plumes)
			lneps(lev) = log(eps(lev)); % log of entrainment rate
		end
		ze_half = 1/2*(ze(2:end)+ze(1:end-1));
		dlneps_dz_half = (lneps(2:end) - lneps(1:end-1)) ./ (ze(2:end) - ze(1:end-1));
		dlneps_dz = interp1(ze_half, dlneps_dz_half, ze);
		dlneps_dz = fillmissing(dlneps_dz, 'nearest');
		ta_pa_cd = [ta_cd, pa_cd];
		deriv_dry(:,1) = dtdz_dpdz(:,1);
		if par.reversible
			par.r_t = r(end); % moisture at LCL is the total moisture of rising parcel
			[z_cs, ta_pa_cs] = ode45(@(z, T_p) sat_rev_z(T_p, par.frz, par), [z_lcl, ze(end)], ta_pa_cd(end,:));
			[z_ce, ta_pa_ce] = ode45(@(z, T_p) sat_zx_z(z, T_p, z_lcl, eps, eps_p, dlneps_dz, ze, h_b, par.frz, par), [z_lcl, ze(end)], ta_pa_cd(end,:));
		else
			[z_cs, ta_pa_cs] = ode45(@(z, T_p) sat_z(T_p, par.frz, par), [z_lcl, ze(end)], ta_pa_cd(end,:));
			[z_ce, ta_pa_ce] = ode45(@(z, T_p) sat_zx_z(z, T_p, z_lcl, eps, eps_p, dlneps_dz, ze, h_b, par.frz, par), [z_lcl, ze(end)], ta_pa_cd(end,:));
		end
		for i = 1:length(z_cs)
			if par.reversible
			    [dt_dp_cs(i, :), qsat_cs(i, 1)] = sat_rev_z(ta_pa_cs(i,:), par.frz, par);
			else
			    [dt_dp_cs(i, :), qsat_cs(i, 1)] = sat_z(ta_pa_cs(i,:), par.frz, par);
			end
		    dt_dp_csd(i, :) = dry_z([ta_pa_cs(i,:)], par);
		end
		for i = 1:length(z_ce)
			if par.reversible
			    [dt_dp_ce(i, :), qsat_ce(i, 1), eps_zce(i, 1)] = sat_zx_z(z_ce(i), ta_pa_ce(i,:), z_lcl, eps, eps_p, dlneps_dz, ze, h_b, par.frz, par);
			else
			    [dt_dp_ce(i, :), qsat_ce(i, 1), eps_zce(i, 1)] = sat_zx_z(z_ce(i), ta_pa_ce(i,:), z_lcl, eps, eps_p, dlneps_dz, ze, h_b, par.frz, par);
			end
		    dt_dp_ced(i, :) = dry_z([ta_pa_ce(i,:)], par);
		end
			deriv_cs(:,1) = dt_dp_cs(:,1);
			deriv_ce(:,1) = dt_dp_ce(:,1);
			deriv_csd(:,1) = dt_dp_csd(:,1);
			deriv_ced(:,1) = dt_dp_ced(:,1);
		z_s(:, 1) = [z_cd; z_cs(2:end)];
		z_e(:, 1) = [z_cd; z_ce(2:end)];
		ta_s(:, 1) = [ta_cd; ta_pa_cs(2:end,1)];
		ta_e(:, 1) = [ta_cd; ta_pa_ce(2:end,1)];
		pa_s(:, 1) = [pa_cd(:); ta_pa_cs(2:end,2)];
		pa_e(:, 1) = [pa_cd(:); ta_pa_ce(2:end,2)];
		qsat_s(:, 1) = [qsat_cd(:, 1); qsat_cs(2:end)];
		qsat_e(:, 1) = [qsat_cd(:, 1); qsat_ce(2:end)];
		eps_z(:, 1) = [zeros(size(qsat_cd)); eps_zce(2:end)];
		dtadz_s(:, 1) = [deriv_dry; deriv_cs(2:end)];
		dtadz_e(:, 1) = [deriv_dry; deriv_ce(2:end)];

		pa_s = interp1(z_s, pa_s, par.z, 'linear', 'extrap');
		pa_e = interp1(z_e, pa_e, par.z, 'linear', 'extrap');
		ta_s = interp1(z_s, ta_s, par.z, 'linear', 'extrap');
		ta_e = interp1(z_e, ta_e, par.z, 'linear', 'extrap');
		qsat_s = interp1(z_s, qsat_s, par.z, 'linear', 'extrap');
		qsat_e = interp1(z_e, qsat_e, par.z, 'linear', 'extrap');
		eps_z = interp1(z_e, eps_z, par.z, 'linear', 'extrap');
		dtadz_s = interp1(z_s, dtadz_s, par.z, 'linear', 'extrap');
		dtadz_e = interp1(z_e, dtadz_e, par.z, 'linear', 'extrap');

		for lev = 1:length(par.z)
			L_s(lev) = calc_L(ta_s(lev));
			L_e(lev) = calc_L(ta_e(lev));
		end

end
