function [gamma, qsat] = cond_z(T_p_rh, r0, params)
    % T_p_rh(1) is temperature
    % T_p_rh(2) is pressure
    % T_p_rh(3) is relative humidity

    esat = calc_esat(T_p_rh(1));
	qsat = calc_q(T_p_rh(2), esat, params);
    e = T_p_rh(3) * esat;

    dt_p_dz = dry_z([T_p_rh(1); T_p_rh(2)], params); 
	de_dz = r0 / (r0 + params.eps) * dt_p_dz(2);
    desat_dz = esat * dt_p_dz(1) * 6743.769 * (1 - 4.8451 / T_p_rh(1)) / (T_p_rh(1) - 4.8451 * log(T_p_rh(1)))^2;
    drh_dz = 1 / esat * de_dz - e / esat^2 * desat_dz;

	gamma = [dt_p_dz; drh_dz];
end
