function [dT_dp, qsat, eps] = sat_romps_z(T_p, a, frz, par)
if nargin < 4 || isempty(frz), frz = 1; end

	% T_p is a 2x1 vector, where T_p(1) is temperature and T_p(2) is pressure
	T = T_p(1);
	p = T_p(2);

	L = calc_L(T, frz);
	esat = calc_esat(T, par.frz);
	qsat = calc_q(p, esat, par);
	rsat = par.eps * esat / (p - esat);
	deriv_dry = dry_z(T_p, par);
	gamma_dry = deriv_dry(1);
	dpdz = deriv_dry(2);

	gamma = gamma_dry * (1 + a + (L * qsat) / (par.Rd * T)) / (1 + a + (L^2 * qsat) / (par.Rv * T^2 * par.cpd));

	ga = L*(-gamma)/(par.Rv*T^2) - par.g/(par.Rd*T);
	eps = a*ga/par.pe;

	dT_dp = [gamma; dpdz];
end
