function [dT_dp, qsat, rh] = sat_romps_z(z, T_p, eps, frz, h1, par)
if nargin < 4 || isempty(frz), frz = 1; end

	% T_p is a 2x1 vector, where T_p(1) is temperature and T_p(2) is pressure
	T = T_p(1);
	p = T_p(2);

	L = calc_L(T, frz);
	esat = calc_esat(T, par.frz);
	qsat = calc_q(p, esat, par);
	rsat = par.eps * esat / (p - esat);
	deriv_dry = dry_z(T_p, par);
	gamma_dry = deriv_dry(1);
	dpdz = deriv_dry(2);

	% parameters in the Romps (2014) model
	h2 = h1 + 7000; % top of troposphere
	if z < h1
		del = eps;
	elseif z > h1 & z < h2
		del = eps + pi/(h2-h1) * (sin(pi*(z-h1)/(h2-h1)))/(1+cos(pi*(z-h1)/(h2-h1)));
	else
		del = 0;
	end
	b1 = par.Rv*par.cpd*T^2/L + qsat*L;
	b2 = par.Rv*par.cpd*T^2/L*(del-par.al*eps+par.g/(par.Rd*T))+qsat*L*(del-eps) - par.g;
	b3 = (par.Rv*par.cpd*T/(par.Rd*L) - 1)*par.g*(del-par.al*eps);
	
	gamma = -par.Rv*T^2/L * ((-b2+sqrt(b2^2-4*b1*b3))/(2*b1) + par.g/(par.Rd*T));

	dT_dp = [gamma; dpdz];

	ga = L*(-gamma)/(par.Rv*T^2) - par.g/(par.Rd*T);
	rh = (del + par.al*ga -par.al*eps) / (del + ga - par.al * eps);
end
