function [dT_dp, qsat, eps] = sat_so_z(z, T_p, eps0, frz, par)
if nargin < 4 || isempty(frz), frz = 1; end

	% T_p is a 2x1 vector, where T_p(1) is temperature and T_p(2) is pressure
	T = T_p(1);
	p = T_p(2);

	L = calc_L(T, frz);
	esat = calc_esat(T, par.frz);
	qsat = calc_q(p, esat, par);
	rsat = par.eps * esat / (p - esat);
	deriv_dry = dry_z(T_p, par);
	gamma_dry = deriv_dry(1);
	dpdz = deriv_dry(2);

	eps = eps0/z;

	gamma = -par.g/par.cpd * (1+(L*qsat)/(par.Rd*T) + (eps*qsat*L*(1-80/100))/(par.g))/(1+(L^2*qsat)/(par.cpd*par.Rv*T^2));

	dT_dp = [gamma; dpdz];

end
