function [dT_dp, qsat, eps_z] = sat_zx_z(z, T_p, z_lcl, eps, eps_p, dlneps_dz, ze, h_b, frz, par)
if nargin < 4 || isempty(frz), frz = 1; end
	% T_p is a 2x1 vector, where T_p(1) is temperature and T_p(2) is pressure
	T = T_p(1);
	p = T_p(2);

	L = calc_L(T, frz);
	esat = calc_esat(T, par.frz);
	qsat = calc_q(p, esat, par);
	rsat = par.eps * esat / (p - esat);
	deriv_dry = dry_z(T_p, par);
	gamma_dry = deriv_dry(1);
	dpdz = deriv_dry(2);

	eps_z = interp1(ze, eps, z); % evaluate bulk entrainment rate at current level
	eps_pz = interp1(ze, eps_p, z); % evaluate plume entrainment rate at current level
	dlneps_dz_z = interp1(ze, dlneps_dz, z);

	h = T + (par.g*z + qsat*L)/par.cpd;
	lambda = 1/(1+par.eta*eps_pz*(z-z_lcl))*dlneps_dz_z;

	gamma = -par.g/par.cpd * (1+(L*qsat)/(par.Rd*T) + (eps_pz*qsat*L*(1-80/100))/(par.g)-lambda*par.cpd/par.g*(h-h_b) )/(1+(L^2*qsat)/(par.cpd*par.Rv*T^2));

	dT_dp = [gamma; dpdz];

end
