function boxplot2(X,Y,thick,lowq,upq)
% BOXPLOT2 plots median (red, quantile 0.5), interquartile range (blue,
% quantiles 0.25 and 0.75) and non-outliers range (black, quantiles defined
% by inputs low (lower percentile) and up (upper percentile))
%
% Syntax: boxplot2(X,Y)
%
% Example:
%      X=1:2;
%      Y{1}=1:100;
%      Y{2}=101:200;
%      subplot(311), boxplot2(X,Y)     ,  xlim([0 3])
%      subplot(312), boxplot2(X,Y,0.4) ,  xlim([0 3])
%      subplot(313), boxplot2(X,Y,0.2) ,  xlim([0 3])
%
% Check boxplot3 (mean and standard error)
%
% Bugs? rpavao@gmail.com

if nargin<2
    help boxplot2
else
    if nargin<3
        thick=0.4;
    end
        
    hold on
    for g=1:length(X)
        data=Y{g};
        yvalues=quantile(data,[lowq/100 0.25 0.5 0.75 upq/100 ]);
        xvalues=thick*[-1 +1]+X(g);
        xvalues2=0.5*thick*[-1 +1]+X(g);
        plot(xvalues,[1 1]*yvalues(3),'r')
        plot([xvalues(1) xvalues(2) xvalues(2) xvalues(1) xvalues(1)],[yvalues(2) yvalues(2) yvalues(4) yvalues(4) yvalues(2)],'b')
        plot([1 1]*X(g),yvalues(1:2),'k')
        plot(xvalues2,[1 1]*yvalues(1),'k')
        plot([1 1]*X(g),yvalues(4:5),'k')
        plot(xvalues2,[1 1]*yvalues(5),'k')
    end
end
