function plots_2d(i, model, x_2d_lat, x_2d_lon, x_3d_lat, x_2dt, idx_mask, type, prefix, par, clima_type)

	% global settings
	set(0, 'DefaultLineLineWidth', 1.1);
	set(0, 'DefaultFigureUnits', 'inches', 'DefaultFigurePosition', par.ppos_wide);
	set(0, 'DefaultTextInterpreter', 'latex');
	set(0, 'DefaultLegendInterpreter', 'latex');
	set(0, 'DefaultAxesTickLabelInterpreter', 'latex');
	par.fs = 9;
	par.ppos_verywide = [0, 0, 33/3, 7/3];
	par.navy = 0.2*[0, 0.447, 0.741];
	par.darkblue = 0.5*[0, 0.447, 0.741];
	par.blue = [0, 0.447, 0.741];
	par.orange = [0.85, 0.325, 0.098];
	par.yellow = [0.929, 0.694, 0.125];
	par.purple = [0.494, 0.184, 0.556];
	par.green = [0.466, 0.674, 0.188];
	par.cyan = [0.301, 0.745, 0.933];
	par.maroon = [0.635, 0.078, 0.184];
	par.brown = 0.5*[0.635, 0.078, 0.184];
	par.darkbrown = 0.2*[0.635, 0.078, 0.184];
	par.purple = 0.5*[0.4940, 0.1840, 0.5560];

	lim_wap = 5e-2;
	lim_pr = 10e-5;
	lim_idx = 1;
	[longrid, latgrid] = meshgrid(x_2d_lon, x_2d_lat);
	[lon3dgrid, lat3dgrid] = meshgrid(x_2d_lon, x_3d_lat);
	[lon2dgrid, lat2dgrid] = meshgrid(x_2d_lon, x_2d_lat);
	
	[~, idx35n] = min(abs(x_2d_lat - 35));
	[~, idx35s] = min(abs(x_2d_lat + 35));

	if strcmp(type{1}, 'am2') & any(contains(fieldnames(x_2dt), 'cld'))
		% plot total cloud fraction (lat)
		figure(); clf; hold all;
		htot = plot(x_2d_lat, zmean(x_2dt.cldt{i}), '-k');
		hhigh = plot(x_2d_lat, zmean(x_2dt.cldh{i}), '--k');
		hmid = plot(x_2d_lat, zmean(x_2dt.cldm{i}), '-.k');
		hlow = plot(x_2d_lat, zmean(x_2dt.cldl{i}), ':k');
		xlabel('lat (deg)'); ylabel('cloud frac. (%)');
		legend([htot, hhigh, hmid, hlow], 'total', 'high', 'mid', 'low', 'location', 'eastoutside');
		set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
		set(gca, 'xlim', [-90 90], 'xtick', -90:30:90);
		printname = sprintf([par.localdir clima_type model '/' prefix 'zon_cld_tot'], par.ta_bnd, par.ta_bnd);
		print(printname, '-dpng', '-loose', '-r300');
		close;
	end

	% plot w500 (lat)
	figure(); clf; hold all;
	plot(x_2d_lat, zmean(x_2dt.w500{i}), '-k');
	hline(0, ':k');
	vline(0, ':k');
	xlabel('lat (deg)'); ylabel('w500 (Pa/s)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90);
	printname = sprintf([par.localdir clima_type model '/' prefix 'zon_w500'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot climatological precip and evap (lat)
	figure(); clf; hold all;
	plot(x_2d_lat, nanmean(x_2dt.pr{i}, 1), 'linewidth', 1.1);
	plot(x_2d_lat, nanmean(x_2dt.evspsbl{i}, 1), 'linewidth', 1.1);
	plot(x_2d_lat, nanmean(x_2dt.pr{i}, 1) - nanmean(x_2dt.evspsbl{i}, 1), '-k', 'linewidth', 1.1);
	xlabel('lat (deg)'); ylabel('mass flux (kg/m$^2$/s)');
	legend('P', 'E', 'P - E', 'location', 'eastoutside')
	hline(0, '-k');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'ylim', [-inf inf]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'zon_pr'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot climatological precip (full) and convective precip (lat)
	figure(); clf; hold all;
	plot(x_2d_lat, nanmean(x_2dt.pr{i}, 1), '-k', 'linewidth', 1.1);
	plot(x_2d_lat, nanmean(x_2dt.prc{i}, 1), '--k', 'linewidth', 1.1);
	xlabel('lat (deg)'); ylabel('mass flux (kg/m$^2$/s)');
	legend('$\mathrm{P_t}$', '$\mathrm{P_c}$', 'location', 'eastoutside')
	hline(0, '-k');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'ylim', [-inf inf]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'zon_prc'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot climatological idx (lat)
	figure(); clf; hold all;
	plot(x_2d_lat, nanmean(x_2dt.idx{i}, 1), 'linewidth', 1.1);
	xlabel('lat (deg)'); ylabel('index S (dimensionless)');
	hline(0, '-k');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'ylim', [-inf inf]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'zon_idx'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot lat x lon figures
	plots_2d_ll

end
