function plots_2d(id_t, model, x_2d_lat, x_2d_lon, x_3d_lat, x_2d_orig, idx_mask, type, prefix, par, clima_type)

	if ~exist([par.localdir clima_type model '/' num2str(id_t)], 'dir')
		mkdir([par.localdir clima_type model '/' num2str(id_t)]);
	end

	% global settings
	set(0, 'DefaultLineLineWidth', 1.1);
	set(0, 'DefaultFigureUnits', 'inches', 'DefaultFigurePosition', par.ppos_wide);
	set(0, 'DefaultTextInterpreter', 'latex');
	set(0, 'DefaultLegendInterpreter', 'latex');
	set(0, 'DefaultAxesTickLabelInterpreter', 'latex');
	par.fs = 9;
	par.ppos_verywide = [0, 0, 33/3, 7/3];
	par.navy = 0.2*[0, 0.447, 0.741];
	par.darkblue = 0.5*[0, 0.447, 0.741];
	par.blue = [0, 0.447, 0.741];
	par.orange = [0.85, 0.325, 0.098];
	par.yellow = [0.929, 0.694, 0.125];
	par.purple = [0.494, 0.184, 0.556];
	par.green = [0.466, 0.674, 0.188];
	par.cyan = [0.301, 0.745, 0.933];
	par.maroon = [0.635, 0.078, 0.184];
	par.brown = 0.5*[0.635, 0.078, 0.184];
	par.darkbrown = 0.2*[0.635, 0.078, 0.184];
	par.purple = 0.5*[0.4940, 0.1840, 0.5560];

	lim_wap = 5e-2;
	lim_pr = 10e-5;
	lim_idx = 1;
	[longrid, latgrid] = meshgrid(x_2d_lon, x_2d_lat);
	[lon3dgrid, lat3dgrid] = meshgrid(x_2d_lon, x_3d_lat);
	[lon2dgrid, lat2dgrid] = meshgrid(x_2d_lon, x_2d_lat);
	
	[~, idx35n] = min(abs(x_2d_lat - 35));
	[~, idx35s] = min(abs(x_2d_lat + 35));

	% plot w500 (lat x lon)
	figure(); clf; hold all;
	cmp = colCog(20);
	colormap(cmp);
	contourf(lon3dgrid, lat3dgrid, x_2d_orig.w500(:,:,id_t)', lim_wap*[-10:0.1:10], 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	caxis([-lim_wap lim_wap]);
	cb = colorbar('limits', [-lim_wap lim_wap], 'ticks', [-0.05:0.01:0.05], 'location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, '$\omega_{500}$ (Pa/s)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-90 90], 'ytick', -90:30:90);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'w500'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot w500 (lat)
	figure(); clf; hold all;
	plot(x_3d_lat, zmean(x_2d_orig.w500(:,:,id_t)), '-k');
	hline(0, ':k');
	vline(0, ':k');
	xlabel('lat (deg)'); ylabel('w500 (Pa/s)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'zon_w500'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot pr - ev (lat x lon)
	figure(); clf; hold all;
	cmp = colCog(20);
	colormap(cmp);
	contourf(longrid, latgrid, x_2d_orig.pr(:,:,id_t)' - x_2d_orig.evspsbl(:,:,id_t)', lim_pr*[-10:0.1:10], 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	caxis([-lim_pr lim_pr]);
	cb = colorbar('limits', [-lim_pr lim_pr], 'ticks', 1e-5*[-10:2:10], 'location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, 'P - E (kg/m$^2$/s)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-90 90], 'ytick', -90:30:90);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'p_minus_e'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot climatological precip and evap (lat)
	figure(); clf; hold all;
	plot(x_2d_lat, nanmean(x_2d_orig.pr(:,:,id_t), 1), 'linewidth', 1.1);
	plot(x_2d_lat, nanmean(x_2d_orig.evspsbl(:,:,id_t), 1), 'linewidth', 1.1);
	plot(x_2d_lat, nanmean(x_2d_orig.pr(:,:,id_t), 1) - nanmean(x_2d_orig.evspsbl(:,:,id_t), 1), '-k', 'linewidth', 1.1);
	xlabel('lat (deg)'); ylabel('mass flux (kg/m$^2$/s)');
	legend('P', 'E', 'P - E', 'location', 'eastoutside')
	hline(0, '-k');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'ylim', [-inf inf]);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'zon_pr'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot climatological precip (full) and convective precip (lat)
	figure(); clf; hold all;
	plot(x_2d_lat, nanmean(x_2d_orig.pr(:,:,id_t), 1), '-k', 'linewidth', 1.1);
	plot(x_2d_lat, nanmean(x_2d_orig.prc(:,:,id_t), 1), '--k', 'linewidth', 1.1);
	xlabel('lat (deg)'); ylabel('mass flux (kg/m$^2$/s)');
	legend('$\mathrm{P_t}$', '$\mathrm{P_c}$', 'location', 'eastoutside')
	hline(0, '-k');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'ylim', [-inf inf]);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'zon_prc'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot idx mask (lat x lon)
	figure(); clf; hold all;
	colormap(gray);
	imagesc(x_2d_lon, x_3d_lat, idx_mask(:, :, id_t)');
	xlabel('longitude'); ylabel('latitude');
	% caxis([0 lim_idx]);
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-90 90], 'ytick', -90:30:90);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'idx_mask'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot ps (lat x lon)
	figure(); clf; hold all;
	contourf(lon2dgrid(idx35s:idx35n, :), lat2dgrid(idx35s:idx35n, :), x_2d_orig.ps(:, idx35s:idx35n, id_t)'/100, 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	cb = colorbar('location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, 'surface pressure (hPa)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'ps'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot ts (lat x lon)
	figure(); clf; hold all;
	contourf(lon3dgrid(idx35s:idx35n, :), lat3dgrid(idx35s:idx35n, :), x_2d_orig.tsurf(:, idx35s:idx35n, id_t)', 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	cb = colorbar('location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, 'surface temperature (K)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'tsurf'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot hs (lat x lon)
	figure(); clf; hold all;
	contourf(lon3dgrid(idx35s:idx35n, :), lat3dgrid(idx35s:idx35n, :), x_2d_orig.hsurf(:, idx35s:idx35n, id_t)', 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	cb = colorbar('location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, 'surface RH (\%)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'hsurf'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot tsurf (lat x lon)
	figure(); clf; hold all;
	contourf(lon2dgrid(idx35s:idx35n, :), lat2dgrid(idx35s:idx35n, :), x_2d_orig.tas(:, idx35s:idx35n, id_t)', 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	cb = colorbar('location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, '2-m temperature (K)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'tas'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot t500 (lat x lon)
	figure(); clf; hold all;
	contourf(lon2dgrid(idx35s:idx35n, :), lat2dgrid(idx35s:idx35n, :), x_2d_orig.t500(:, idx35s:idx35n, id_t)', 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	cb = colorbar('location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, '500 hPa temperature (K)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 't500'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot t300 (lat x lon)
	figure(); clf; hold all;
	contourf(lon2dgrid(idx35s:idx35n, :), lat2dgrid(idx35s:idx35n, :), x_2d_orig.t300(:, idx35s:idx35n, id_t)', 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	cb = colorbar('location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, '300 hPa temperature (K)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 't300'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot ts300 (lat x lon)
	figure(); clf; hold all;
	contourf(lon2dgrid(idx35s:idx35n, :), lat2dgrid(idx35s:idx35n, :), x_2d_orig.ts300(:, idx35s:idx35n, id_t)', 'linecolor', 'none');
	xlabel('longitude'); ylabel('latitude');
	cb = colorbar('location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, '300 hPa temperature (K)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'ts300'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot OP (lat x lon)
	figure(); clf; hold all;
	cmp = colCog(20);
        colormap(cmp);
	contourf(lon2dgrid(idx35s:idx35n, :), lat2dgrid(idx35s:idx35n, :), 100 * (x_2d_orig.ts300(:, idx35s:idx35n, id_t)'-x_2d_orig.t300(:, idx35s:idx35n, id_t)')./x_2d_orig.t300(:, idx35s:idx35n, id_t)', -50:0.1:50, 'linecolor', 'none');
	caxis([-10 10]);
	cb = colorbar('limits', [-10 10], 'ticks', [-10:2:10], 'location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, '$(T_{s300} - T_{300}) / T_{300} $ (unitless)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_verywide);
	set(gca, 'xlim', [0 360], 'xtick', [0:60:360], 'ylim', [-30 30], 'ytick', -30:10:30);
	printname = sprintf([par.localdir clima_type model '/' num2str(id_t) '/' prefix 'op'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

end
