function plots_3d(i, model, x_3d_lat, x_3d_plev, x_3d, x_3dzt, fields_3d, prefix, par, clima_type)

	% global settings
	set(0, 'DefaultLineLineWidth', 1.1);
	set(0, 'DefaultFigureUnits', 'inches', 'DefaultFigurePosition', par.ppos_wide);
	set(0, 'DefaultTextInterpreter', 'latex');
	set(0, 'DefaultLegendInterpreter', 'latex');
	set(0, 'DefaultAxesTickLabelInterpreter', 'latex');
	par.fs = 9;
	par.navy = 0.2*[0, 0.447, 0.741];
	par.darkblue = 0.5*[0, 0.447, 0.741];
	par.blue = [0, 0.447, 0.741];
	par.orange = [0.85, 0.325, 0.098];
	par.yellow = [0.929, 0.694, 0.125];
	par.purple = [0.494, 0.184, 0.556];
	par.green = [0.466, 0.674, 0.188];
	par.cyan = [0.301, 0.745, 0.933];
	par.maroon = [0.635, 0.078, 0.184];
	par.brown = 0.5*[0.635, 0.078, 0.184];
	par.darkbrown = 0.2*[0.635, 0.078, 0.184];
	par.purple = 0.5*[0.4940, 0.1840, 0.5560];

	lim_ucomp = 15;
	lim_vcomp = 0.2;
	lim_wap = 1e-1;
	[latgrid, pagrid] = meshgrid(x_3d_lat, x_3d_plev/100);

	if all(contains(fields_3d, {'ucomp', 'vcomp'}))
		% plot u velocity (lat x pa)
		figure(); clf; hold all;
		cmp = colCog(20);
		colormap(cmp);
		cint = 2; cintpos = cint:cint:cint*100; cintneg = -fliplr(cintpos);
		contourf(latgrid, pagrid, x_3dzt.ucomp{i}', lim_ucomp*[-10:0.1:10], 'linecolor', 'none');
		xlabel('latitude (deg)'); ylabel('pressure (hPa)');
		caxis([-lim_ucomp lim_ucomp]);
		cb = colorbar('limits', [-lim_ucomp lim_ucomp], 'location', 'eastoutside');
		cb.TickLabelInterpreter = 'latex';
		cb.Label.Interpreter = 'latex';
		ylabel(cb, '$u$ (m/s)');
		set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
		set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
		printname = sprintf([par.localdir clima_type model '/' prefix 'ucomp'], par.ta_bnd, par.ta_bnd);
		print(printname, '-dpng', '-loose', '-r300');
		close;

		% plot v velocity (lat x pa)
		figure(); clf; hold all;
		cmp = colCog(20);
		colormap(cmp);
		contourf(latgrid, pagrid, x_3dzt.vcomp{i}', lim_vcomp*[-10:0.1:10], 'linecolor', 'none');
		xlabel('latitude (deg)'); ylabel('pressure (hPa)');
		caxis([-lim_vcomp lim_vcomp]);
		cb = colorbar('limits', [-lim_vcomp lim_vcomp], 'location', 'eastoutside');
		cb.TickLabelInterpreter = 'latex';
		cb.Label.Interpreter = 'latex';
		ylabel(cb, '$v$ (m/s)');
		set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
		set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
		printname = sprintf([par.localdir clima_type model '/' prefix 'vcomp'], par.ta_bnd, par.ta_bnd);
		print(printname, '-dpng', '-loose', '-r300');
		close;
	end

	% plot w velocity (lat x pa)
	figure(); clf; hold all;
	cmp = colCog(20);
	colormap(cmp);
	contourf(latgrid, pagrid, x_3dzt.wap{i}', lim_wap*[-10:0.1:10], 'linecolor', 'none');
	xlabel('latitude (deg)'); ylabel('pressure (hPa)');
	caxis([-lim_wap lim_wap]);
	cb = colorbar('limits', [-lim_wap lim_wap], 'location', 'eastoutside');
	cb.TickLabelInterpreter = 'latex';
	cb.Label.Interpreter = 'latex';
	ylabel(cb, '$\omega_{500}$ (Pa/s)');
	set(gcf, 'PaperUnits', 'inches', 'PaperPosition', par.ppos_wide);
	set(gca, 'xlim', [-90 90], 'xtick', -90:30:90, 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'wap'], par.ta_bnd, par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot vertical temperature profile
	figure(); clf; hold all;
	plot(x_3d.ta{i}, x_3d_plev/100, '-k');
	plot(x_3d.ta_s{i}, x_3d_plev/100, '-', 'color', par.orange);
	xlabel('T (K)'); ylabel('p (hPa)');
	axis('tight');
	set(gcf, 'paperunits', 'inches', 'paperposition', par.ppos);
	set(gca, 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'ta_%g'], par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot vertical entrainment profiles (bulk plume)
	figure(); clf; hold all;
	plot(x_3d.eps_z{i}, x_3d_plev/100, '-k');
	plot(x_3d.idx_eps_z{i}, x_3d_plev/100, '--k');
	xlabel('$\epsilon$ (1/m)'); ylabel('p (hPa)');
	axis('tight');
	set(gcf, 'paperunits', 'inches', 'paperposition', par.ppos);
	set(gca, 'xlim', [0, 1e-3], 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'eps_%g'], par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot vertical entrainment profiles (zero buoyancy bulk plume)
	figure(); clf; hold all;
	plot(x_3d.eps_so_z{i}, x_3d_plev/100, '-k');
	plot(x_3d.idx_eps_so_z{i}, x_3d_plev/100, '--k');
	xlabel('$\epsilon$ (1/m)'); ylabel('p (hPa)');
	axis('tight');
	set(gcf, 'paperunits', 'inches', 'paperposition', par.ppos);
	set(gca, 'xlim', [0, 1e-3], 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'eps_so_%g'], par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot vertical entrainment profiles (romps)
	figure(); clf; hold all;
	plot(x_3d.eps_r_z{i}, x_3d_plev/100, '-k');
	plot(x_3d.idx_eps_r_z{i}, x_3d_plev/100, '--k');
	xlabel('$\epsilon$ (1/m)'); ylabel('p (hPa)');
	axis('tight');
	set(gcf, 'paperunits', 'inches', 'paperposition', par.ppos);
	set(gca, 'xlim', [0, 1e-3], 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'eps_r_%g'], par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot vertical entrainment profiles (all)
	figure(); clf; hold all;
	plot(x_3d.eps_z{i}, x_3d_plev/100, '-k');
	plot(x_3d.eps_so_z{i}, x_3d_plev/100, ':k');
	plot(x_3d.eps_r_z{i}, x_3d_plev/100, '--k');
	xlabel('$\epsilon$ (1/m)'); ylabel('p (hPa)');
	axis('tight');
	set(gcf, 'paperunits', 'inches', 'paperposition', par.ppos);
	set(gca, 'xlim', [0, 1e-3], 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
	printname = sprintf([par.localdir clima_type model '/' prefix 'eps_all_%g'], par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

	% plot vertical net large scale entrainment profiles
	figure(); clf; hold all;
	plot(x_3d.net_eps_l{i}, x_3d_plev/100, '-k');
	plot(x_3d.idx_net_eps_l{i}, x_3d_plev/100, '--k');
	xlabel('$\frac{1}{M}\frac{\partial M}{\partial z}$ (1/m)'); ylabel('p (hPa)');
	axis('tight');
	set(gcf, 'paperunits', 'inches', 'paperposition', par.ppos);
	set(gca, 'yscale', 'log', 'ydir', 'reverse', 'ylim', [par.pmin 1000], 'ytick', [par.pmin 300 400:200:1000]);
	vline(0, '-k');
	printname = sprintf([par.localdir clima_type model '/' prefix 'net_eps_l_%g'], par.ta_bnd);
	print(printname, '-dpng', '-loose', '-r300');
	close;

end
